﻿'# Title    : SlimDX Hidden Box Demo
'# Author   : Sascha Bajus
'# Created  : 01/2009
'# Copyright © 2009 Sascha Bajus

'# Die Demo zeigt die Grundlage des Alphafadings über die Materialeigenschaften.
'# 2 Boxen die ineinander liegen und rotieren werden gerendert.
'# Die Transparenz der äusseren Box wird über die Materialeigenschaften
'# verändert.
'# Bei jedem Renderdurchang wird zeitbasiert der Alphawert des Material
'# neu berechnet und zugewiesen.

#Region "Copyright© Information (German)"
' Diese Software wird bereitgestellt "wie sie ist", ohne jegliche ausdrückliche oder 
' stillschweigende Gewährleistung. In keinem Fall kann der Author haftbar gemacht werden
' für Schäden, die aus der Nutzung dieser Software entstanden sind.
'
' Es ist erlaubt, diese Software für jeden Zweck zu nutzen, einschließlich der kommerziellen 
' Anwendungen, und sie zu verändern, vorbehaltlich der folgenden Einschränkungen: 
'
' 1. Der Ursprung dieser Software darf nicht falsch dargestellt werden; Sie dürfen nicht behaupten, 
'    dass Sie der Urheber der Original-Software sind. Wenn Sie diese Software in einem Produkt 

' 2. Altered-Source-Versionen müssen klar als solche gekennzeichnet, und dürfen nicht als 
'    Original-Software dargestellt werden.
'
' 3. Diese Informationen dürfen nicht entfernt oder geändert werden.
#End Region
#Region "Copyright© Information (English)"
' This software is provided 'as-is', without any express or implied warranty. In no event will 
' the authors be held liable for any damages arising from the use of this software.
'
' Permission is granted to anyone to use this software for any purpose, including commercial 
' applications, and to alter it and redistribute it freely, subject to the following restrictions:
'
' 1. The origin of this software must not be misrepresented; you must not claim that you wrote 
'    the original software. If you use this software in a product, an acknowledgment in the 
'    product documentation would be appreciated but is not required.
'
' 2. Altered source versions must be plainly marked as such, and must not be misrepresented 
'    as being the original software.
'
' 3. This notice may not be removed or altered from any source distribution.
'
#End Region



Imports SlimDX
Imports SlimDX.Direct3D9
Imports SlimDX.DirectInput
Imports sdxBaseEngine


Public Class Project : Inherits SDX9BaseEngine

    Private _Box As Mesh            '#Meshobject
    Private _matAlpha As Material   '#Material for Alphafading
    Private _alpha As Double        '#Timebased Alphavalue

    Public Sub New()

        AddHandler dxRenderScene, AddressOf render
        AddHandler dxKeyboardState, AddressOf keyboard
        AddHandler dxLoadObjectsSettings, AddressOf loading
        AddHandler dxEngineClosed, AddressOf ExitAplication
        '---------------------------------------------

        If dxEngine("SlimDX - BaseEngine - Hidden Box Demo") = False Then CloseBaseEngine()
    End Sub

#Region "Loading"
    Private Sub loading()
        '#setup 3D Box
        _Box = Mesh.CreateBox(dxDevice, 1, 1, 1)
        '#Setup Camposition
        dxCamera.currentPosition = New Vector3(0, 1, -3)

        '#Enable Z-Buffer
        dxZBuffer.Enabled = True
        '#setup Basic Light
        dxLightsFFP.EnableLighting = True
        dxLightsFFP.EnableDirectionalLight = True

        dxEngine.TargetBufferColor = Color.CornflowerBlue
    End Sub

#End Region
#Region "## render ##"
    Private Sub render()

        dxTexture.resetTexture(0)

        '#Box1  - rotateY timebased position 0,0,0
        dxLightsFFP.SetDefaultMaterial() 'White
        dxTransformWorld = dxMatrix.TimebasedRotationXYZ(New Vector3(0.002, 0.002, 0)) * Matrix.Scaling(0.5, 0.5, 0.5)
        _Box.DrawSubset(0)


        '#Box2 - rotate -Y timebases position 0,0,0 with Alphafading Material
        '#calculate new Alphavalue
        _alpha = dxGametime.Timefading(0.001, 0.5, 1)
        '#setup new diffuse Material
        _matAlpha.Diffuse = Color.FromArgb(CInt(_alpha * 255), 255, 255, 255)
        '#set Material to device
        dxDevice.Material = _matAlpha

        '#Enable Alphablendind, disable Culling
        dxTexture.AlphaBlending1(Cull.None) = True
        dxTransformWorld = dxMatrix.TimebasedRotationY(-0.002)
        _Box.DrawSubset(0)
        '#disable Alpha, enable Culling
        dxTexture.AlphaBlending1() = False


        '#Draw FPS
        dx2DText.DrawFPS()
    End Sub
#End Region
#Region "## keyboard ##"
    Private Sub keyboard()
        '#Close and dispose all
        If dxEngine.KeyPressed(Key.Escape) Then CloseBaseEngine()
    End Sub
#End Region
#Region "## Exit Application ##"
    Private Sub ExitAplication()
        If Not _Box Is Nothing Then _Box.Dispose()
        End
    End Sub
#End Region

    Private Sub InitializeComponent()
        Dim resources As System.ComponentModel.ComponentResourceManager = New System.ComponentModel.ComponentResourceManager(GetType(Project))
        Me.SuspendLayout()
        '
        'Project
        '
        Me.ClientSize = New System.Drawing.Size(284, 262)
        Me.Icon = CType(resources.GetObject("$this.Icon"), System.Drawing.Icon)
        Me.Name = "Project"
        Me.ResumeLayout(False)

    End Sub
End Class
